A plot with three panels. The top panels show the MCMC run (left) and the prior (gren) and posterior (grey) distributions for deltaR, the age offset (assumed to be constant among all C14 ages). The main panel shows the age distribution of the inner ring, and also the placements of the radiocarbon dates on the calibration curve taking the best (mode) calendar age. Grey dots show the placements of the dates with the modelled age offset.
draw.MCMCrings(
yrs,
dR,
dat,
cc,
Us,
delta.R,
delta.STD,
BCAD,
cal.lim = c(),
cal.lab = c(),
C14.lim = c(),
C14.lab = c(),
mar = c(3, 3, 1, 1),
mgp = c(1.7, 0.7, 0),
main.height = 0.55,
dist.height = 0.5,
name = c(),
name.loc = "topleft",
MCMC.col = grey(0.3),
prior.col = "green",
prior.lab = "delta.R",
text.col = "red",
post.col = rgb(0, 0, 0, 0.3),
cc.col = rgb(0, 0, 1, 0.5),
dets.col = "black",
adj.col = grey(0.5)
)A plot with the MCMC run, the prior and posterior for deltaR, and the posterior age estimate together with the placements of the radiocarbon dates.
The modelled years.
The modelled delta.R values.
The data, extracted from the .csv file.
Calibration curve to be used. Could be 1 (IntCal20; default), 2 (Marine20), 3 (SHCal20) or 4 (custom curve).
Energy of the MCMC run (for the topleft graph).
Prior for the mean delta.R.
Prior for the standard deviation of delta.R.
The calendar scale of graphs and age output-files is in cal BP by default, but can be changed to BC/AD using BCAD=TRUE.
The limits for the bottom calendar axis. Calculated automatically by default.
The labels for the bottom calendar axis (default age.lab="cal BP" or "BC/AD".
The limits for the bottom C14 axis. Calculated automatically by default.
The labels for the bottom y-axis. Defaults to 14C BP with superscript 14, so expression(""^14*C~BP).
Axis margins. Defaults to mar=c(3, 3, 1, 1).
Axis text margins (where should titles, labels and tick marks be plotted). Defaults to mgp=c(1.7, .7, .0).
Height of the main panel, relative to the top panels. Defaults to 0.55.
Height of the age distribution, relative to the vertical axis extent. Defaults to 0.5.
Name to plot in the main panel.
Location of the name, defaults to name.loc="topleft".
Colour of the MCMC run. Defaults to dark grey, MCMC.col=grey(0.3).
Colour of the prior for the delta.R distribution, default green.
Label of the prior. Defaults to "delta.R".
Colour of the text describing the delta.R prior. Defaults to red.
Colour of the posterior distributions. Defaults to semi-transparent dark grey.
Colour of the calibration curve. Defaults to semi-transparent blue, dist.col=rgb(0,0,1,0.5).
Colour of the radiocarbon determinations ranges. Defaults to "black" but could also give colours for each individual, date, e.g., dets.col=1:10.
Colour of the adjusted C14 dates. Defaults to grey.
Maarten Blaauw, Marco Aquino Lopez